/* *******************************************************************
   Webserver

   How it all works together:

   page   0.htm         includes the f.css in the header
          404           a response when the requested resource is not available
          204           a response when the browser will not get any content
   css    f.css         a css stylesheet for all on flash (program) memory
   ***************************************************************** */

void server20Setup() {
  server.on("/",            handlePage20);       // the home page
  server.on("/20.htm",      handlePage20);       // a more sophisticated page
  server.on("/f.css",       handleCss);          // a stylesheet
  server.on("/favicon.ico", handle204);          // not available, send 204
  server.onNotFound(handleNotFound);             // show a typical HTTP Error 404 page
}


// a list of pages to have them in the navigation bar
const char htmlNavigation[] = ("<nav><p>"
                               "<a href='10.htm'>Simple Page</a>"
                               " | <a href='20.htm'>Simple Output Text only</a>"
                               " | <a href='30.htm'>Simple Output Variables</a>"
                               " | <a href='40.htm'>Input Fields</a>"
                               " | <a href='50.htm'>Pin Buttons</a>"
                               " | <a href='55.htm'>Action Buttons</a>"
                               " | <a href='70.htm'>Output Values with Update</a>"
                               "</p></nav>\n");

// the html output
// Advice: check your generated HTML output if it is valid HTML: https://validator.w3.org

// *** Home ***  0.htm
// just some basic examples
void handlePage20() {
  String message;
  String reserve(5000);                 // maximum size of page

  message =  F("<!DOCTYPE html>\n"
               "<html lang=\"en\">\n"   // english or any other language code you using for your page content
               "<head>\n"
               "<title>" TXT_BOARDNAME " - Board " );
  message += USE_BOARD;
  message += F("</title>\n"
               "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">\n"
               "<meta name=\"viewport\" content=\"width=device-width\">\n"
               "<link rel='stylesheet' type='text/css' href='f.css'>\n"
               "</head>\n");
  message += F("<body>\n");
  message += F("<header>\n"
               "<h1>" TXT_BOARDNAME " - Board " );
  message += USE_BOARD;
  message += F("</h1>\n");
  message += htmlNavigation;  // just some Fixt text with a navigation bar
  message += F("</header>\n"
               "<main>\n");

  // print whatever you need on the web page:
  message += F("<article>\n"
               "<h2>Comments</h2>\n"
               "<p>This is just a simple Demo of a Webserver running on an ESP32 or ESP8266. "
               "Give your webpage a well definied structure. Put the content in 'main'. </p>"
               "<p>Style your webpage with CSS. Avoid using inline styles. "
               "</p>\n");
  message += F("</article>\n");

  // end of content
  message += F("</main>\n");
  // a footer line
  message += F("<footer>\n"
               "<p>Running since:");
  message += millis() / 1000;
  message += F("<p>\n"
               "</footer>\n");
  message += F("</body>\n"
               "</html>\n");
  server.send(200, "text/html", message);
}

// output of stylesheet
// this is a straight forward example how to generat a static page from program memory
void handleCss() {
  String message;
  String reserve(2000);                 // maximum size of page
  message = F("*{font-family:sans-serif}\n"
              "body{margin:10px}\n"
              "h1, h2{color:white;background:#1279b1;text-align:center}\n"
              "h1{margin:1px;padding:5px;font-size:1.2em}\n"
              "h2{font-size:1.1em}\n"
              "main{text-align:center}\n"
              "nav{background-color:silver;margin:1px;padding:5px;font-size:0.8em}\n"
              "article{margin:0.2em;padding:0.1em;border-style:solid;border-width:thin;border-color:#C0C0C0;text-align:center;background-color:#E5E5E5}\n"
              "footer p{font-size:0.7em;color:dimgray;background:silver;text-align:center;margin-bottom:5px}\n"
              "input[type=button], input[type=submit], input[type=reset]{width:8em}\n"
              "label{text-align:right}\n"
             );
  server.send(200, "text/css", message);
}

// Output a "404 not found" page. It includes the parameters which comes handy for test purposes.
void handleNotFound() {
  Serial.println(F("D124 handleNotFound()"));
  String message;
  String reserve(5000);                 // maximum size of page
  message += F("404 - File Not Found\n"
               "URI: ");
  message += server.uri();
  message += F("\nMethod: ");
  message += (server.method() == HTTP_GET) ? "GET" : "POST";
  message += F("\nArguments: ");
  message += server.args();
  message += F("\n");
  for (uint8_t i = 0; i < server.args(); i++) {
    message += " " + server.argName(i) + ": " + server.arg(i) + "\n";
  }
  server.send(404, "text/plain", message);
}

// Output a "204 no content" page.
// Used for the favicon.ico request (as we don't have any favicon currently)
void handle204() {
  server.send(204);                // this page doesn't send back content
}
//
