/* *******************************************************************
   Webserver

   a form to switch on/off Pins on the ESP

   page   50.htm         buttons to switch pins

   ***************************************************************** */

void server50Setup() {
  server.on("/50.htm", handlePage50);         // Buttons to switch pins
}

// global variables for this example
constexpr uint8_t outputPinA = 2;      // might be LED on the ESP8266 module - active LOW
constexpr uint8_t outputPinB = 16;     // a LED on the NODEMCU - active LOW

void example50Setup() {
  pinMode(outputPinA, OUTPUT);
  pinMode(outputPinB, OUTPUT);
}


// *** Button ***  50.htm
// two buttons to change pin state
// this example asumes INVERS logic (LOW switches on the LED)
void handlePage50() {
  String message;
  String reserve(5000);                // maximum size of page

  // if the browser has send commands to change pins
  if (server.hasArg("outputPinA"))  {
    if (server.arg("outputPinA") == "on")
      digitalWrite(outputPinA, LOW);
    else
      digitalWrite(outputPinA, HIGH);
  }

  if (server.hasArg("outputPinB"))  {
    if (server.arg("outputPinB") == "on")
      digitalWrite(outputPinB, LOW);
    else
      digitalWrite(outputPinB, HIGH);
  }

  message =  F("<!DOCTYPE html>\n"
               "<html lang='en'>\n"    // english or any other language code you using for your page content
               "<head>\n"
               "<title>" TXT_BOARDNAME " - Board ");
  message += USE_BOARD;
  message += F("</title>\n"
               "<meta http-equiv='content-type' content='text/html; charset=utf-8'>\n"
               "<meta name='viewport' content='width=device-width'>\n"
               "<link rel='stylesheet' type='text/css' href='f.css'>\n" // defined in server20
               "</head>\n");
  message += F("<body>\n");
  message += F("<header>\n<h1>" TXT_BOARDNAME " - Board ");
  message += USE_BOARD;
  message += F("</h1>\n");
  message += htmlNavigation; // just some fixt text with a navigation bar, defined in server20
  message += F("</header>\n"
               "<main>\n");

  // print whatever you need on the web page:
  message += F("<article>\n"
               "<h2>Example 3: Form for Output Pins</h2>\n"
               "<form method='post' action='50.htm' name='pinForm'>\n");  // we let send the form to this page

  message += F("<p>Pin A: <input type='submit' name='outputPinA' value='on'> <input type='submit' name='outputPinA' value='off'> is currently ");
  digitalRead(outputPinA) == LOW ? message += F("on") : message += F("off");
  message += F("</p>\n");

  message += F("<p>Pin B: <input type='submit' name='outputPinB' value='on'> <input type='submit' name='outputPinB' value='off'> is currently ");
  digitalRead(outputPinB) == LOW ? message += F("on") : message += F("off");
  message += F("</p>\n");

  message += F("</form>\n");                               // end of the form
  message += F("</article>\n");
  message += F("</main>\n");
  message += F("<footer>\n"
               "<p>Running since:");
  message += millis() / 1000;
  message += F(" seconds<p>\n"
               "</footer>\n");
  message += F("</html>\n");
  server.send(200, "text/html", message);
}
//
