/* *******************************************************************
   Webserver

   automatic update of variables with FetchAPI/JavaScript

   page   70.htm         includes the f.css and the j.js
          json           the data in JSON format
          j.js           a JavaScript to parse the JSON and update the page

   ***************************************************************** */

void server70Setup() {
  server.on("/70.htm", handlePage70);         // another page, another handle
  server.on("/json",   handleJson70);         // output of data in JSON
  server.on("/j.js",   handleJs70);           // the JavaScript for the FetchAPI
}

// some user variables
int autoInteger = 123;
float autoFloat = 12.34;
String autoString = "Test";

// a more advanced page with na
// *** Variables ***  1.htm
void handlePage70() {
  String message;
  String reserve(5000);                // maximum size of page

  message =  F("<!DOCTYPE html>\n"
               "<html lang=\"en\">\n"  // english or any other language code you using for your page content
               "<head>\n"
               "<title>" TXT_BOARDNAME " - Board " );
  message += USE_BOARD;
  message += F("</title>\n"
               "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">\n"
               "<meta name=\"viewport\" content=\"width=device-width\">\n"
               "<link rel=\"stylesheet\" type=\"text/css\" href=\"f.css\">\n" // defined in server20
               "<script src='j.js'></script>\n"
               "</head>\n");
  message += F("<body>\n");
  message += F("<header>\n<h1>" TXT_BOARDNAME " - Board " );
  message += USE_BOARD;
  message += F("</h1>\n");
  message += htmlNavigation;           // just some fixt text with a navigation bar, defined in server20
  message += F("</header>\n"
               "<main>\n");

  // print whatever you need on the web page:
  message += F("<article>\n"
               "<h2>Values to be updated  by FetchAPI</h2>\n"
               "<p>The autoInteger variable is currently: <span id='autoInteger'>");  // you must identify the place of the value with an unique ID. You can use the HTML inline tag span.
  message += autoInteger;
  message += F("</span></p>\n");                                                      // close the inline tag span
  message += F("<p>The autoFloat variable is currently: <span id='autoFloat'>");
  message += autoFloat;
  message += F("</span></p>\n");
  message += F("<p>The autoString is currently: <span id='autoString'>");
  message += autoString;
  message += F("</span></p>\n");
  message += F("<p>The millis() is currently: <span id='millis'>");
  message += millis();
  message += F("</span></p>\n");
  message += F("<p>equals to: <span id='min'>");
  message += millis() / 60000;
  message += F("</span> min and <span id='sec'>");
  message += millis() % 60000;
  message += F("</span> sec</p>\n");
  message += F("</article>\n");

  message += F("</main>\n"); // end of content
  // a footer line
  message += F("<footer>\n"
               "<p>Running since:<span id='ss'>");
  message += millis() / 1000;
  message += F("</span> seconds<p>\n"
               "</footer>\n");
  message += F("</body>\n"
               "</html>\n");

  server.send(200, "text/html", message);
}

// Output: send data to browser as JSON
// you can use a JSON library or just generate your own JSON
// after modification always check if the JSON is still valid. Just call the JSON (json) in your webbrowser and check.
void handleJson70() {
  String message = "";
  message.reserve(5000);
  uint32_t currentMillis = millis();
  // change some values
  autoInteger = random(0, 1000);
  autoFloat = random(0, 1000) / 100.0;
  if (currentMillis % 2) autoString = "odd "; else autoString = "even";
  //
  message = (F("{\"ss\":"));             // Start of JSON and the first object "ss":
  message += currentMillis / 1000;
  message += (F(",\"millis\":"));        // the key/name of the variable needs to be send in ", to print a " you must escpate it with a backslash \"
  message += currentMillis;
  message += (F(",\"autoInteger\":"));   // the key/name of the variable needs to be send in ", to print a " you must escpate it with a backslash \"
  message += autoInteger;
  message += (F(",\"autoFloat\":"));
  message += autoFloat;
  message += (F(",\"autoString\":\""));  // strings like text must be enclosed in "". To print a " you must escape it with a backslash \"
  message += autoString;
  message += F("\"");                    // closing " escaped with a backslash
  // variables specific for this usecase:

  message += (F("}"));                           // End of JSON
  server.send(200, "application/json", message); // set MIME type https://www.ietf.org/rfc/rfc4627.txt
}


// Output: a fetch API / JavaScript
// a function in the JavaScript uses fetch API to request a JSON file from the webserver and updates the values on the page if the object names and ID are the same
void handleJs70() {
  const uint8_t interval = 5; // update interval in seconds
  String message;
  message.reserve(5000);
  message += F("const url ='json';\n"
               "function renew(){\n"
               " document.getElementById('sec').style.color = 'blue';\n"                                               // if the timer starts the request, the second gets blue
               " fetch(url)\n" // Call the fetch function passing the url of the API as a parameter
               " .then(response => {return response.json();})\n"
               " .then(jo => {\n"
               "   document.getElementById('sec').innerHTML = Math.floor(jo['ss'] % 60);\n"                            // example how to change a value in the HTML page
               "   for (var i in jo)\n"
               "   {\n"
               "    if (document.getElementById(i)) document.getElementById(i).innerHTML = jo[i];\n"                   // as long as the JSON name fits to the HTML id, the value will be replaced
               "   }\n"  // update checkboxe
               // add other fields here (e.g. the delivered JSON name doesn't fit to the html id
               // finally, update the runtime
               "   if (jo['ss'] > 60) {document.getElementById('min').innerHTML = Math.floor(jo['ss'] / 60 % 60);}\n"
               "   document.getElementById('sec').style.color = '';\n"                                                 // if everything was ok, the second will be default color again
               " })\n"
               " .catch(function() {\n"                                        // this is where you run code if the server returns any errors
               "  document.getElementById('sec').style.color = 'red';\n"
               " });\n"
               "}\n"
               "document.addEventListener('DOMContentLoaded', renew, setInterval(renew, ");
  message += interval * 1000UL;
  message += F("));\n");
  server.send(200, "text/javascript", message);
}
//
